# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)

from ... import models


# THX EMAIL BACKEND
class ThxEmailBackendSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_emailbackend_thx_email_backend'
        model = models.ThxEmailBackend
        fields = '__all__'


class ThxEmailBackendListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_emailbackend_thx_email_backend_list'
        model = models.ThxEmailBackend
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class ThxEmailBackendRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_emailbackend_thx_email_backend_retrieve'
        model = models.ThxEmailBackend
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class ThxEmailBackendCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_emailbackend_thx_email_backend_create'
        model = models.ThxEmailBackend
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return ThxEmailBackendListSerializer(instance, context=self.context).data


class ThxEmailBackendUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_emailbackend_thx_email_backend_update'
        model = models.ThxEmailBackend
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return ThxEmailBackendRetrieveSerializer(instance, context=self.context).data


class ThxEmailBackendPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_emailbackend_thx_email_backend_partial_update'
        model = models.ThxEmailBackend
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return ThxEmailBackendRetrieveSerializer(instance, context=self.context).data


class ThxEmailBackendEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_emailbackend_thx_email_backend_enable'
        model = models.ThxEmailBackend
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return ThxEmailBackendRetrieveSerializer(instance, context=self.context).data


class ThxEmailBackendDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_emailbackend_thx_email_backend_disable'
        model = models.ThxEmailBackend
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return ThxEmailBackendRetrieveSerializer(instance, context=self.context).data
