# -*- coding: utf-8 -*-

from rest_framework import exceptions, viewsets
from rest_framework.decorators import action
from thx.api.views import ThuxViewMixin

from ... import models
from . import serializers


# THX EMAIL BACKEND
class ThxEmailBackendViewSet(ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.ThxEmailBackend.objects.all()
    serializer_class = serializers.ThxEmailBackendSerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile')
        qs = super().get_queryset()
        if user.is_superuser and profile == 'superuser':
            return qs
        return qs.none()

    def check_permissions(self, request):
        super().check_permissions(request)
        user = self.request.user
        profile = self.kwargs.get('profile')
        if user.is_superuser and profile == 'superuser':
            if self.action in [
                'list', 'retrieve', 'create', 'update', 'partial_update', 'destroy', 'enable', 'disable',
            ]:
                return
        raise exceptions.PermissionDenied()

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'ThxEmailBackend{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)
